diff --git a/nuxt4/app/components/auth/ApplicationsList.vue b/nuxt4/app/components/auth/ApplicationsList.vue
index 0fe80a0..67b11a6 100644
--- a/nuxt4/app/components/auth/ApplicationsList.vue
+++ b/nuxt4/app/components/auth/ApplicationsList.vue
@@ -11,6 +11,27 @@
+
+
+
diff --git a/nuxt4/app/components/WindowTitleBar.vue b/nuxt4/app/components/WindowTitleBar.vue
index 08c6095..014b862 100644
--- a/nuxt4/app/components/WindowTitleBar.vue
+++ b/nuxt4/app/components/WindowTitleBar.vue
@@ -72,8 +72,11 @@ onMounted(() => {
transition: all 0.3s ease;
/* Bloquear interacción con elementos debajo */
pointer-events: auto;
/* Eliminar cualquier margen o gap */
margin: 0;
+ border: none;
+ border-bottom: none;
+ box-shadow: none;
}
.titlebar-content {
@@ -72,8 +72,11 @@ onMounted(() => {
/* Bloquear interacción con elementos debajo */
pointer-events: auto;
- /* Eliminar cualquier margen o gap */
+ /* Eliminar cualquier margen, gap o border */
margin: 0;